/* image.h is part of UDAV
 * Copyright (C) 2007-2014 Alexey Balakin <mathgl.abalakin@gmail.ru>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License
 * as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
//-----------------------------------------------------------------------------
#ifndef IMAGE_H
#define IMAGE_H
//-----------------------------------------------------------------------------
#include <FL/Fl_RGB_Image.H>

extern MGL_EXPORT Fl_RGB_Image img_load;
extern MGL_EXPORT Fl_RGB_Image img_save;
extern MGL_EXPORT Fl_RGB_Image img_calc;
extern MGL_EXPORT Fl_RGB_Image img_undo;
extern MGL_EXPORT Fl_RGB_Image img_redo;
extern MGL_EXPORT Fl_RGB_Image img_copy;
extern MGL_EXPORT Fl_RGB_Image img_paste;
extern MGL_EXPORT Fl_RGB_Image img_find;
extern MGL_EXPORT Fl_RGB_Image img_prop;
extern MGL_EXPORT Fl_RGB_Image img_alpha;
extern MGL_EXPORT Fl_RGB_Image img_light;
extern MGL_EXPORT Fl_RGB_Image img_grid;
extern MGL_EXPORT Fl_RGB_Image img_move;
extern MGL_EXPORT Fl_RGB_Image img_orig;
extern MGL_EXPORT Fl_RGB_Image img_update;
extern MGL_EXPORT Fl_RGB_Image img_stop;
extern MGL_EXPORT Fl_RGB_Image img_insert;
extern MGL_EXPORT Fl_RGB_Image img_print;
extern MGL_EXPORT Fl_RGB_Image img_goL;
extern MGL_EXPORT Fl_RGB_Image img_goU;
extern MGL_EXPORT Fl_RGB_Image img_zoomIn;
extern MGL_EXPORT Fl_RGB_Image img_zoomOut;
extern MGL_EXPORT Fl_RGB_Image img_goD;
extern MGL_EXPORT Fl_RGB_Image img_goR;
extern MGL_EXPORT Fl_RGB_Image img_next;
extern MGL_EXPORT Fl_RGB_Image img_play;
extern MGL_EXPORT Fl_RGB_Image img_prev;
extern MGL_EXPORT Fl_RGB_Image img_plot;
extern MGL_EXPORT Fl_RGB_Image img_system;
extern MGL_EXPORT Fl_RGB_Image img_info;
extern MGL_EXPORT Fl_RGB_Image img_help;
extern MGL_EXPORT Fl_RGB_Image img_delete;
extern MGL_EXPORT Fl_RGB_Image img_objectU;
extern MGL_EXPORT Fl_RGB_Image img_objectD;
extern MGL_EXPORT Fl_RGB_Image img_layer;
extern MGL_EXPORT Fl_RGB_Image img_new;
extern MGL_EXPORT Fl_RGB_Image img_clear;
extern MGL_EXPORT Fl_RGB_Image img_plus;
extern MGL_EXPORT Fl_RGB_Image img_minus;
extern MGL_EXPORT Fl_RGB_Image img_udav;
extern MGL_EXPORT Fl_RGB_Image img_fname;
extern MGL_EXPORT Fl_RGB_Image img_curve;
extern MGL_EXPORT Fl_RGB_Image img_svn;
extern MGL_EXPORT Fl_RGB_Image img_adjust;
extern MGL_EXPORT Fl_RGB_Image img_reload;
extern MGL_EXPORT Fl_RGB_Image img_zoom12;
extern MGL_EXPORT Fl_RGB_Image img_zoom21;
extern MGL_EXPORT Fl_RGB_Image img_pause;
extern MGL_EXPORT Fl_RGB_Image img_icons;
extern MGL_EXPORT Fl_RGB_Image img_form;
#endif
